@@ -416,7 +416,7 @@ class Log:
 
         return (ct_method, ct_number)
 
-    def take_screenshot_log(self, driver, stack_item="", test_number=""):
+    def take_screenshot_log(self, driver, description="", stack_item="", test_number=""):
         """
         [Internal]
 
@@ -439,7 +439,7 @@ class Log:
             stack_item = self.get_testcase_stack()
 
         if stack_item == "setUpClass":
-            stack_item = self.get_file_name("testsuite")
+            stack_item = f'{self.get_testcase_stack()}_{self.get_file_name("testsuite")}'
 
         if not test_number:
             test_number = f"{stack_item.split('_')[-1]} -" if stack_item else ""
@@ -451,12 +451,12 @@ class Log:
 
         today = datetime.today()
 
-        if self.search_stack("log_error"):
+        if self.search_stack("log_error") and not description:
             screenshot_file = self.screenshot_file_name("error", stack_item)
         elif self.search_stack("CheckResult"):
-            screenshot_file = self.screenshot_file_name("CheckResult_result_divergence", stack_item)
+            screenshot_file = self.screenshot_file_name("CheckResult", stack_item)
         else:
-            screenshot_file = self.screenshot_file_name(stack_item)
+            screenshot_file = self.screenshot_file_name(description=description, stack_item=stack_item)
 
         if self.config.debug_log:
             logger().debug(f"take_screenshot_log in:{datetime.now()}\n")
